pub trait StreamNotifier:
Send
+ Sync
+ 'static {
// Required methods
fn subscribe(&self) -> StreamNotification;
fn current_sequence(&self) -> u64;
fn advance(&self, seq: u64);
}Expand description
In-process notification capability for stream subscribers.
Required Methods
Sourcefn subscribe(&self) -> StreamNotification
fn subscribe(&self) -> StreamNotification
Atomically snapshot the visible batch frontier and return a notifier that wakes when the frontier may have advanced.
Sourcefn current_sequence(&self) -> u64
fn current_sequence(&self) -> u64
Highest batch sequence currently visible to live subscribers.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".